==> haskell-swagger2-2.2.2-54-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: swagger2
version: 2.2.2
id: swagger2-2.2.2-DpYe9CM8Hz6Dyab7UhVjQ5
key: swagger2-2.2.2-DpYe9CM8Hz6Dyab7UhVjQ5
license: BSD-3-Clause
copyright: (c) 2015-2016, GetShopTV
maintainer: nickolay@getshoptv.com
author: Nickolay Kudasov
homepage: https://github.com/GetShopTV/swagger2
synopsis: Swagger 2.0 data model
description:
    This library is inteded to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.
    .
    The original Swagger 2.0 specification is available at http://swagger.io/specification/.
category: Web, Swagger
abi: a58b226be5ce3c4db20309e6e81c541c
exposed: True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.ParamSchema
    Data.Swagger.Schema Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions
import-dirs: /usr/lib/ghc-8.4.3/site-local/swagger2-2.2.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/swagger2-2.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/swagger2-2.2.2
hs-libraries: HSswagger2-2.2.2-DpYe9CM8Hz6Dyab7UhVjQ5
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    template-haskell-2.13.0.0 time-1.8.0.2 transformers-0.5.5.0
    mtl-2.2.2 text-1.2.3.0
    base-compat-batteries-0.10.1-LLh6zuxO9A0GhuBNRjv95y
    aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL
    generics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    insert-ordered-containers-0.2.1.0-GNfoRVrH08VAp7BwWglyRK
    lens-4.17-4C4gMEkWPox35sMHxQ6P7t
    network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa
    uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             base-compat-batteries-0.10.1-LLh6zuxO9A0GhuBNRjv95y=5587f60ad32ffc1f6a8671336ccb43fe
             aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL=912860ab3519756596367ddae154025c
             generics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom=69b8ea707aa80039da4ef8d7dea33061
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=483bd81a950f6e9e13c6265205a34bbd
             insert-ordered-containers-0.2.1.0-GNfoRVrH08VAp7BwWglyRK=d087a72bb3abcc984e53f5ada267faf8
             lens-4.17-4C4gMEkWPox35sMHxQ6P7t=4cb9fc45e7308a0ad354f525c2839895
             network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu=43a70846fe67ebce9998ba267f800e6d
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa=81e1d2b217f05c2ba43642acf6d96f3b
             uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71=073bf76fdf6ac46f8363958226adfe9d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html: /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-swagger2-2.2.2-55-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: swagger2
version: 2.2.2
id: swagger2-2.2.2-3C0IsVVXH324OylZ35Kcdx
key: swagger2-2.2.2-3C0IsVVXH324OylZ35Kcdx
license: BSD-3-Clause
copyright: (c) 2015-2016, GetShopTV
maintainer: nickolay@getshoptv.com
author: Nickolay Kudasov
homepage: https://github.com/GetShopTV/swagger2
synopsis: Swagger 2.0 data model
description:
    This library is inteded to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.
    .
    The original Swagger 2.0 specification is available at http://swagger.io/specification/.
category: Web, Swagger
abi: eff0572ef57d4bdeb305431c0df3a47b
exposed: True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.ParamSchema
    Data.Swagger.Schema Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions
import-dirs: /usr/lib/ghc-8.4.3/site-local/swagger2-2.2.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/swagger2-2.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/swagger2-2.2.2
hs-libraries: HSswagger2-2.2.2-3C0IsVVXH324OylZ35Kcdx
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    template-haskell-2.13.0.0 time-1.8.0.2 transformers-0.5.5.0
    mtl-2.2.2 text-1.2.3.0
    base-compat-batteries-0.10.1-LLh6zuxO9A0GhuBNRjv95y
    aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL
    generics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    insert-ordered-containers-0.2.1.0-GNfoRVrH08VAp7BwWglyRK
    lens-4.17-4C4gMEkWPox35sMHxQ6P7t
    network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa
    uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             base-compat-batteries-0.10.1-LLh6zuxO9A0GhuBNRjv95y=5587f60ad32ffc1f6a8671336ccb43fe
             aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL=912860ab3519756596367ddae154025c
             generics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom=69b8ea707aa80039da4ef8d7dea33061
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=483bd81a950f6e9e13c6265205a34bbd
             insert-ordered-containers-0.2.1.0-GNfoRVrH08VAp7BwWglyRK=d087a72bb3abcc984e53f5ada267faf8
             lens-4.17-4C4gMEkWPox35sMHxQ6P7t=4cb9fc45e7308a0ad354f525c2839895
             network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu=43a70846fe67ebce9998ba267f800e6d
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa=81e1d2b217f05c2ba43642acf6d96f3b
             uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71=073bf76fdf6ac46f8363958226adfe9d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html: /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
